@@ -11,28 +11,22 @@
 #
 ##############################################################################
 """Utilities for the genome coverage"""
-import re
-import ast
 import os
-import sys
 import random
-
-from sequana import mixture
-
-from sequana.lazy import pandas as pd
-from sequana.lazy import numpy as np
-from sequana.lazy import pylab
-from pylab import mean as pymean
-
-from sequana.tools import gc_content
-from sequana.genbank import GenBank
-from sequana.errors import SequanaException
-from sequana.summary import Summary
-from sequana.stats import evenness
-
-from easydev import do_profile, TempFile, Progress
+import sys
 
 import colorlog
+from easydev import Progress, TempFile
+
+from sequana.errors import BadFileFormat
+from sequana.genbank import GenBank
+from sequana.gff3 import GFF3
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+from sequana.stats import evenness
+from sequana.summary import Summary
+from sequana.tools import gc_content
 
 logger = colorlog.getLogger(__name__)
 
@@ -188,7 +182,7 @@ class GenomeCov(object):
     def __init__(
         self,
         input_filename,
-        genbank_file=None,
+        annotation_file=None,
         low_threshold=-4,
         high_threshold=4,
         ldtr=0.5,
@@ -204,7 +198,7 @@ class GenomeCov(object):
             genomecov run. This is just a 3-column file. The first column is a
             string (chromosome), second column is the base postion and third
             is the coverage.
-        :param str genbank_file: annotation file of your referenve.
+        :param str annotation_file: annotation file of your reference (GFF3/Genbank).
         :param float low_threshold: threshold used to identify under-covered
             genomic region of interest (ROI). Must be negative
         :param float high_threshold: threshold used to identify over-covered
@@ -234,7 +228,7 @@ class GenomeCov(object):
         self._feature_dict = None
         self._gc_window_size = None
         self.gc_dict = None
-        self._genbank_filename = None
+        self._annotation_filename = None
         self._window_size = None
 
         self.chunksize = chunksize
@@ -242,8 +236,8 @@ class GenomeCov(object):
         self.quiet_progress = quiet_progress
 
         # the user choice have the priorities over csv file
-        if genbank_file:
-            self.genbank_filename = genbank_file
+        if annotation_file:
+            self.annotation_filename = annotation_file
 
         self.input_filename = input_filename
 
@@ -293,7 +287,7 @@ class GenomeCov(object):
         logger.error(
             "AttributeError: You can't set attribute.\n"
             "GenomeCov.feature_dict is set when"
-            "GenomeCov.genbank_filename is set."
+            "GenomeCov.annotation_filename is set."
         )
         sys.exit(1)
 
@@ -311,20 +305,23 @@ class GenomeCov(object):
             self._gc_window_size = n
 
     @property
-    def genbank_filename(self):
+    def annotation_filename(self):
         """Get or set the genbank filename to annotate ROI detected with
         :meth:`ChromosomeCov.get_roi`. Changing the genbank filename will
         configure the :attr:`GenomeCov.feature_dict`.
         """
-        return self._genbank_filename
+        return self._annotation_filename
 
-    @genbank_filename.setter
-    def genbank_filename(self, genbank_filename):
-        if os.path.isfile(genbank_filename):
-            self._genbank_filename = os.path.realpath(genbank_filename)
+    @annotation_filename.setter
+    def annotation_filename(self, annotation_filename):
+        if os.path.isfile(annotation_filename):
+            self._annotation_filename = os.path.realpath(annotation_filename)
 
-            gbk = GenBank(genbank_filename)
-            self._feature_dict = gbk.genbank_features_parser()
+            try:
+                gff = GFF3(annotation_filename)
+                self._feature_dict = gff.get_features_dict()
+            except BadFileFormat:
+                self._feature_dict = GenBank(annotation_filename).genbank_features_parser()
         else:
             logger.error("FileNotFoundError: The genbank file doesn't exist.")
             sys.exit(1)
@@ -372,7 +369,9 @@ class GenomeCov(object):
         if Nchunk > 1:
             pb = Progress(Nchunk)
         i = 0
-        for chunk in pd.read_table(input_filename, header=None, sep="\t", usecols=[0], chunksize=self.chunksize, dtype="string"):
+        for chunk in pd.read_table(
+            input_filename, header=None, sep="\t", usecols=[0], chunksize=self.chunksize, dtype="string"
+        ):
             # accumulate length
             N += len(chunk)
 
@@ -475,8 +474,8 @@ class GenomeCov(object):
             self.thresholds.get_args(), self.window_size, self.circular
         )
 
-        if self.genbank_filename:
-            header += " genbank:" + self.genbank_filename
+        if self.annotation_filename:
+            header += " genbank:" + self.annotation_filename
 
         if self.gc_window_size:
             header += " gc_window_size:{0}".format(self.gc_window_size)
@@ -564,7 +563,13 @@ class ChromosomeCov(object):
         N = self.bed.positions[self.chrom_name]["N"]
         toskip = self.bed.positions[self.chrom_name]["start"]
         self.iterator = pd.read_table(
-            self.bed.input_filename, skiprows=toskip, nrows=N, header=None, sep="\t", chunksize=self.chunksize, dtype={0: "string"}
+            self.bed.input_filename,
+            skiprows=toskip,
+            nrows=N,
+            header=None,
+            sep="\t",
+            chunksize=self.chunksize,
+            dtype={0: "string"},
         )
         if N <= self.chunksize:
             # we can load all data into memory:
@@ -994,7 +999,7 @@ class ChromosomeCov(object):
         data = data.replace(0, np.nan)
         data = data.dropna()
 
-        if data.empty: #pragma: no cover
+        if data.empty:  # pragma: no cover
             self._df["scale"] = np.ones(len(self.df), dtype=int)
             self._df["zscore"] = np.zeros(len(self.df), dtype=int)
             # define arbitrary values
@@ -1089,7 +1094,7 @@ class ChromosomeCov(object):
 
         try:
             filtered = self.get_rois()
-        except Exception as err: #pragma: no cover
+        except Exception as err:  # pragma: no cover
             raise (err)
         finally:
             # restore the original threshold
@@ -1157,7 +1162,7 @@ class ChromosomeCov(object):
                     return FilteredGenomeCov(data, self.thresholds, features[self.chrom_name], step=self.binning)
             else:
                 return FilteredGenomeCov(data, self.thresholds, step=self.binning)
-        except KeyError: #pragma: no cover
+        except KeyError:  # pragma: no cover
             logger.error(
                 "Column zscore is missing in data frame.\n"
                 "You must run compute_zscore before get low coverage."
@@ -1259,7 +1264,7 @@ class ChromosomeCov(object):
         if len(df) > 1000000 and sample is True:
             logger.info("sub sample data for plotting the coverage")
             NN = int(len(df) / 1000000)
-        else: #pragma: no cover
+        else:  # pragma: no cover
             NN = 1
 
         # the main coverage plot
@@ -1294,7 +1299,7 @@ class ChromosomeCov(object):
             m4 = high_zcov[high_zcov > 0]
             if len(m4) == 0:
                 m4 = 3
-            else: 
+            else:
                 m4 = m4.max(skipna=True)
             # ignore values equal to zero to compute mean average
             m3 = df[df["cov"] > 0]["cov"].mean()
@@ -1305,7 +1310,7 @@ class ChromosomeCov(object):
 
         try:
             pylab.tight_layout()
-        except: #pragma: no cover
+        except:  # pragma: no cover
             pass
 
         if filename:
@@ -1328,7 +1333,7 @@ class ChromosomeCov(object):
         pylab.xlabel("Z-score", fontsize=fontsize)
         try:
             pylab.tight_layout()
-        except: #pragma: no cover
+        except:  # pragma: no cover
             pass
         pylab.xlim([-max_z, max_z])
         if filename:
@@ -1345,7 +1350,7 @@ class ChromosomeCov(object):
         try:
             self.mixture_fitting.data = d
             self.mixture_fitting.plot(self.gaussians_params, bins=bins, Xmin=0, Xmax=max_z)
-        except ZeroDivisionError: #pragma: no cover
+        except ZeroDivisionError:  # pragma: no cover
             return
 
         pylab.grid(True)
@@ -1354,7 +1359,7 @@ class ChromosomeCov(object):
 
         try:
             pylab.tight_layout()
-        except: #pragma: no cover
+        except:  # pragma: no cover
             pass
         if filename:
             pylab.savefig(filename)
@@ -1371,7 +1376,7 @@ class ChromosomeCov(object):
         ec="k",
         filename=None,
         zorder=10,
-        **kw_hist
+        **kw_hist,
     ):
         """
 
@@ -1450,7 +1455,7 @@ class ChromosomeCov(object):
         ymax=100,
         contour=True,
         cmap="BrBG",
-        **kwargs
+        **kwargs,
     ):
         """Plot histogram 2D of the GC content versus coverage"""
         if Nlevels is None or Nlevels == 0:
@@ -1482,9 +1487,9 @@ class ChromosomeCov(object):
                     norm=norm,
                     fontsize=fontsize,
                     cmap=cmap,
-                    **kwargs
+                    **kwargs,
                 )
-            except: #pragma: no cover
+            except:  # pragma: no cover
                 h2.plot(
                     bins=bins,
                     xlabel="Per-base coverage",
@@ -1494,13 +1499,13 @@ class ChromosomeCov(object):
                     contour=False,
                     norm=norm,
                     fontsize=fontsize,
-                    **kwargs
+                    **kwargs,
                 )
 
         pylab.ylim([ymin, ymax])
         try:
             pylab.tight_layout()
-        except: #pragma: no cover
+        except:  # pragma: no cover
             pass
 
         if filename:
@@ -1564,7 +1569,7 @@ class ChromosomeCov(object):
                 X,
             ) = np.histogram(data, bins=bins, density=True)
             return {"X": list(X[1:]), "Y": list(Y)}
-        except: #pragma: no cover
+        except:  # pragma: no cover
             return {"X": [], "Y": []}
 
     def get_summary(self, C3=None, C4=None, stats=None, caller="sequana.bedtools"):
@@ -1800,7 +1805,7 @@ class FilteredGenomeCov(object):
         while feature["type"] in FilteredGenomeCov._feature_not_wanted:
             try:
                 feature = next(iter_feature)
-            except StopIteration: #pragma: no cover 
+            except StopIteration:  # pragma: no cover
                 print(
                     "Features types ({0}) are not present in the annotation"
                     " file. Please change what types you want".format(feature["type"])
@@ -1813,36 +1818,31 @@ class FilteredGenomeCov(object):
             while feature["gene_end"] <= region["start"]:
                 try:
                     feature = next(iter_feature)
-                except:
+                except StopIteration:
                     break
             while feature["gene_start"] < region["end"]:
                 # A feature exist for detected ROI
                 feature_exist = True
                 # put locus_tag in gene field if gene doesn't exist
-                try:
-                    feature["gene"]
-                except KeyError: #pragma: no cover
+                if "gene" not in feature:
                     try:
                         feature["gene"] = feature["locus_tag"]
-                    except:
+                    except KeyError:
                         feature["gene"] = "None"
+
                 # put note field in product if product doesn't exist
-                try:
-                    feature["product"]
-                except KeyError: #pragma: no cover
+                if "product" not in feature:
                     try:
                         feature["product"] = feature["note"]
-                    except:
+                    except KeyError:
                         feature["product"] = "None"
-                # FIXME what that ?
-                # if region["start"] == 237433:
-                #    print(dict(region, **feature))
+
                 region_ann.append(dict(region, **feature))
                 try:
                     feature = next(iter_feature)
                 except StopIteration:
                     break
-            if feature_exist is False:
+            if not feature_exist:
                 region_ann.append(
                     dict(
                         region,
@@ -1853,7 +1853,7 @@ class FilteredGenomeCov(object):
                             "gene": None,
                             "strand": None,
                             "product": None,
-                        }
+                        },
                     )
                 )
         return region_ann
